package com.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.shigongli.common.BaseController;
import com.shigongli.common.ResponseBean;
import com.shigongli.common.ScreenShotUtil;
import com.shigongli.common.StringUtils;
import com.shigongli.constants.StatusConstant;
import com.shigongli.entity.TaPerson;
import com.shigongli.entity.TaShop;
import com.shigongli.entity.TaShopKeeper;
import com.shigongli.service.ITaShopKeeperService;
import com.shigongli.service.ITaShopService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import com.shigongli.service.ITaHouseService;
import com.shigongli.entity.TaHouse;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
    * 房源 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-12-11
 */

@Api(tags = "房源")
@RestController
@RequestMapping("/")
public class TaHouseController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaHouseController.class);

    @Value("${weather-shot.url}")
    String weatherURL;

    @Autowired
    public ITaHouseService iTaHouseService;

    @Autowired
    ITaShopKeeperService iTaShopKeeperService;

    @Autowired
    ITaShopService iTaShopService;

    @Autowired
    ScreenShotUtil screenShotUtil;

//
//    /**
//     * 分页查询列表
//     * @param pageNum
//     * @param pageSize
//     * @return
//     */
//    @RequestMapping(value="/mp/taHouse",method= RequestMethod.GET)
//    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taHouseList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
//									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{
//
//		    IPage<TaHouse> pg = new Page<>(pageNum, pageSize);
//            QueryWrapper<TaHouse> queryWrapper = new QueryWrapper<>();
//            queryWrapper.eq("status", StatusConstant.NORMAL);
//            queryWrapper.orderByDesc("create_date");
//
//            IPage<TaHouse> result = iTaHouseService.page(pg, queryWrapper);
//            return ResponseBean.success(result);
//    }

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/ma/taHouse",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean houseList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                  @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                  HttpServletRequest request) throws Exception{

        TaPerson taPerson = getPerson(request);
        if (null == taPerson) {
            return ResponseBean.error("数据错误, 校验当前人员出错", ResponseBean.ERROR_UNAVAILABLE);
        }

        IPage<TaHouse> pg = new Page<>(pageNum, pageSize);
        IPage<TaHouse> result = iTaHouseService.getHousesOfKeeper(pg, taPerson);
        return ResponseBean.success(result);
    }


    /**
     * 保存对象
     * @param taHouse 实体对象
     * @return
     */
    @RequestMapping(value="/ma/taHouse",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taHouseAdd(@ApiParam("保存内容") @RequestBody TaHouse taHouse,
                                   HttpServletRequest request) throws Exception{
        TaPerson taPerson = getPerson(request);
        List<TaShopKeeper> shopKeeperList = iTaShopKeeperService.getByPerson(taPerson.getPersonId());
        if (null == shopKeeperList || shopKeeperList.size() < 1) {
            return ResponseBean.error("您无权新增房源", ResponseBean.ERROR_UNAVAILABLE);
        }

        if (!StringUtils.isEmpty(taHouse.getShopId())) {
            boolean found = false;
            for (TaShopKeeper keeper: shopKeeperList) {
                if (taHouse.getShopId().equals(keeper.getShopId())) {
                    found = true;
                }
            }

            if (!found) {
                return ResponseBean.error("您无权新增房源, 或房源所属民宿出错", ResponseBean.ERROR_UNAVAILABLE);
            }
        } else {
            if (shopKeeperList.size() > 1) {
                return ResponseBean.error("请设置房源所属民宿", ResponseBean.ERROR_UNAVAILABLE);
            }

            taHouse.setShopId(shopKeeperList.get(0).getShopId());
        }

        if (iTaHouseService.save(taHouse)){
            return ResponseBean.success(taHouse);
        } else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/ma/taHouse/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taHouseDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        TaHouse taHouse = iTaHouseService.getById(id);
        if (null == taHouse || taHouse.getStatus().equals(StatusConstant.DELETE)) {
            return ResponseBean.success("ok");
        }

        taHouse.setStatus(StatusConstant.DELETE);

        return taHouseUpdate(id, taHouse);
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taHouse 实体对象
     * @return
     */
    @RequestMapping(value="/ma/taHouse/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taHouseUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TaHouse taHouse) throws Exception{

        // 不允许修改所属民宿
        taHouse.setShopId(null);

        if (iTaHouseService.updateById(taHouse)){
            return ResponseBean.success(iTaHouseService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 查询当前房源
     * @param id  实体ID
     */
    @RequestMapping(value="/ma/taHouse/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean houseDetail(@ApiParam("房源ID") @PathVariable String id) throws Exception{
        TaHouse taHouse = iTaHouseService.getById(id);
        TaShop taShop = iTaShopService.getById(taHouse.getShopId());
        taHouse.setTaShop(taShop);
        return ResponseBean.success(taHouse);
    }

    @GetMapping("/ma/taHouse/{id}/share")
    @ApiOperation(value="获取分享内容", notes = "获取分享内容", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getShareImage(@ApiParam("房源ID") @PathVariable String id) {
        TaHouse taHouse = iTaHouseService.getById(id);
        if (taHouse == null || StatusConstant.DELETE.equals(taHouse.getStatus())) {
            return ResponseBean.error("房源不存在", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        String city = getCity(taHouse.getAddress());
        if (StringUtils.isEmpty(city)) {
            city = "南京";
        }

        String shot = null;
        try {
            shot = screenShotUtil.shot(String.format(weatherURL, city));
        } catch (Exception e) {
            e.printStackTrace();
        }

        Map<String, Object> res = new HashMap<>();
        res.put("image", shot);
        return ResponseBean.success(res);
    }

    private String getCity (String address) {
        if (StringUtils.isEmpty(address)) {
            return null;
        }

        String[] parts = address.split("市");
        String city = parts[0];
        // 省
        if (city.contains("省")) {
            return city.split("省")[1];
        }
        // 自治区
        if (city.contains("区")) {
            return city.split("区")[1];
        }
        // 直辖市
        if (city.contains("市")) {
            return city.split("市")[1];
        }

        return city;
    }

}
