package com.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.shigongli.common.BaseController;
import com.shigongli.common.ResponseBean;
import com.shigongli.constants.StatusConstant;
import com.shigongli.entity.TaHouseSetting;
import com.shigongli.service.ITaHouseSettingService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.shigongli.service.ITaHouseOrderService;
import com.shigongli.entity.TaHouseOrder;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 房源订单 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-12-11
 */

@Api(tags = "房源订单")
@RestController
@RequestMapping("/")
public class TaHouseOrderController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaHouseOrderController.class);

    @Autowired
    public ITaHouseOrderService iTaHouseOrderService;

    @Autowired
    ITaHouseSettingService iTaHouseSettingService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taHouseOrder",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taHouseOrderList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TaHouseOrder> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaHouseOrder> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaHouseOrder> result = iTaHouseOrderService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taHouseOrder 实体对象
     * @return
     */
    @RequestMapping(value="/taHouseOrder",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taHouseOrderAdd(@ApiParam("保存内容") @RequestBody TaHouseOrder taHouseOrder) throws Exception{

        if (iTaHouseOrderService.save(taHouseOrder)){
            return ResponseBean.success(taHouseOrder);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taHouseOrder/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taHouseOrderDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iTaHouseOrderService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taHouseOrder 实体对象
     * @return
     */
    @RequestMapping(value="/taHouseOrder/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taHouseOrderUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                        @ApiParam("更新内容") @RequestBody TaHouseOrder taHouseOrder) throws Exception{

        if (iTaHouseOrderService.updateById(taHouseOrder)){
            return ResponseBean.success(iTaHouseOrderService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/ma/taHouseOrder/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taHouseOrderGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        TaHouseOrder taHouseOrder = iTaHouseOrderService.getById(id);
        if (null == taHouseOrder || StatusConstant.DELETE.equals(taHouseOrder.getStatus())) {
            return ResponseBean.error("房源设置或订单不存在", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaHouseSetting taHouseSetting = iTaHouseSettingService.getById(taHouseOrder.getSettingId());
        taHouseOrder.setHouseSetting(taHouseSetting);

        return ResponseBean.success(taHouseOrder);
    }
}
