package com.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.shigongli.common.BaseController;
import com.shigongli.common.ResponseBean;
import com.shigongli.constants.StatusConstant;
import com.shigongli.entity.TaPerson;
import com.shigongli.entity.TaShopKeeper;
import com.shigongli.service.ITaHouseService;
import com.shigongli.service.ITaShopKeeperService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.shigongli.service.ITaHouseSurroundService;
import com.shigongli.entity.TaHouseSurround;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * <p>
    * 房源周边 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-12-11
 */

@Api(tags = "房源周边")
@RestController
@RequestMapping("/")
public class TaHouseSurroundController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaHouseSurroundController.class);

    @Autowired
    public ITaHouseSurroundService iTaHouseSurroundService;

    @Autowired
    ITaHouseService iTaHouseService;


    /**
     * 分页查询房源周边, 不传房源则代表所有周边
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/ma/taHouseSurround",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taHouseSurroundList(@ApiParam("页码") @RequestParam(value ="pageNum", defaultValue = "1") Integer pageNum,
                                            @ApiParam("单页数据量") @RequestParam(value ="pageSize", defaultValue = "10") Integer pageSize,
                                            @ApiParam("房源ID") @RequestParam(value ="houseId", required = false) String houseId) throws Exception{

		    IPage<TaHouseSurround> pg = new Page<>(pageNum, pageSize);
            IPage<TaHouseSurround> result = iTaHouseSurroundService.getListByHouseOrNot(pg, houseId);
            return ResponseBean.success(result);
    }

    /**
     * 保存房源周边
     * @param taHouseSurround 实体对象
     * @return
     */
    @RequestMapping(value="/ma/taHouseSurround",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taHouseSurroundAdd(@ApiParam("保存内容") @RequestBody List<TaHouseSurround> taHouseSurroundList) throws Exception{

        if (iTaHouseSurroundService.saveBatch(taHouseSurroundList)){
            return ResponseBean.success(taHouseSurroundList);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/ma/taHouseSurround/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taHouseSurroundDelete(@ApiParam("对象ID") @PathVariable String id,
                                              HttpServletRequest request) throws Exception{
        TaPerson taPerson = getPerson(request);
        TaHouseSurround taHouseSurround = iTaHouseSurroundService.getById(id);
        if (null == taHouseSurround || StatusConstant.DELETE.equals(taHouseSurround.getStatus())) {
            return ResponseBean.error("删除数据不存在, 请重试", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (!iTaHouseService.isOwner(taPerson.getPersonId(), taHouseSurround.getHouseId())) {
            return ResponseBean.error("您无权进行当前操作", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        taHouseSurround.setStatus(StatusConstant.DELETE);

        return taHouseSurroundUpdate(id, taHouseSurround);
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taHouseSurround 实体对象
     * @return
     */
    @RequestMapping(value="/taHouseSurround/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taHouseSurroundUpdate(@ApiParam("对象ID") @PathVariable String id,
                                              @ApiParam("更新内容") @RequestBody TaHouseSurround taHouseSurround) throws Exception{

        if (iTaHouseSurroundService.updateById(taHouseSurround)){
            return ResponseBean.success(iTaHouseSurroundService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taHouseSurround/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taHouseSurroundGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaHouseSurroundService.getById(id));
    }
}
