package com.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.shigongli.common.BaseController;
import com.shigongli.common.ResponseBean;
import com.shigongli.common.StringUtils;
import com.shigongli.constants.StatusConstant;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.shigongli.service.ITaShopService;
import com.shigongli.entity.TaShop;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 民宿店 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-12-11
 */

@Api(tags = "民宿店")
@RestController
@RequestMapping("/")
public class TaShopController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaShopController.class);

    @Autowired
    public ITaShopService iTaShopService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/mp/taShop",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taShopList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TaShop> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaShop> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("status", StatusConstant.NORMAL);
            queryWrapper.orderByDesc("create_date");

            IPage<TaShop> result = iTaShopService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taShop 实体对象
     * @return
     */
    @RequestMapping(value="/mp/taShop",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taShopAdd(@ApiParam("保存内容") @RequestBody TaShop taShop) throws Exception{

        if (StringUtils.isEmpty(taShop.getName())) {
            return ResponseBean.error("名称不能为空", ResponseBean.ERROR_MISSING_PARAMS);
        }

        TaShop origin = iTaShopService.getByName(taShop.getName());
        if (null != origin) {
            return ResponseBean.error("名称重复", ResponseBean.ERROR_MISSING_PARAMS);
        }

        if (iTaShopService.save(taShop)){
            return ResponseBean.success(taShop);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/mp/taShop/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taShopDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        TaShop taShop = iTaShopService.getById(id);
        if (null == taShop || taShop.getStatus().equals(StatusConstant.DELETE)) {
            return ResponseBean.success("ok");
        }

        taShop.setStatus(StatusConstant.DELETE);

        return taShopUpdate(id, taShop);
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taShop 实体对象
     * @return
     */
    @RequestMapping(value="/mp/taShop/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taShopUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TaShop taShop) throws Exception{
        if (StringUtils.isEmpty(taShop.getName())) {
            return ResponseBean.error("名称不能为空", ResponseBean.ERROR_MISSING_PARAMS);
        }

        TaShop origin = iTaShopService.getByName(taShop.getName());
        if (null != origin && !origin.getShopId().equals(id)) {
            return ResponseBean.error("名称重复", ResponseBean.ERROR_MISSING_PARAMS);
        }

        if (iTaShopService.updateById(taShop)){
            return ResponseBean.success(iTaShopService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/mp/taShop/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taShopGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        return ResponseBean.success(iTaShopService.getById(id));
    }
}
