package com.shigongli.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.shigongli.common.StringUtils;
import com.shigongli.constants.StatusConstant;
import com.shigongli.entity.TaPerson;
import com.shigongli.entity.TaShop;
import com.shigongli.entity.TaShopKeeper;
import com.shigongli.mapper.TaShopKeeperMapper;
import com.shigongli.service.ITaShopKeeperService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.shigongli.service.ITaShopService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 店主 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2020-12-11
 */
@Service
public class TaShopKeeperServiceImpl extends ServiceImpl<TaShopKeeperMapper, TaShopKeeper> implements ITaShopKeeperService {

    @Autowired
    ITaShopService iTaShopService;

    @Override
    public void bindPerson(TaPerson taPerson) {
        List<TaShopKeeper> shopKeeperList = getByPhone(taPerson.getPhone());

        if (null == shopKeeperList) {
            return ;
        }

        for (TaShopKeeper shopKeeper: shopKeeperList) {
            shopKeeper.setPersonId(taPerson.getPersonId());
            updateById(shopKeeper);
        }
    }

    @Override
    public List<TaShopKeeper> getByPhone(String phone) {
        QueryWrapper<TaShopKeeper> queryWrapper = new QueryWrapper<TaShopKeeper>()
                .eq("phone", phone)
                .eq("status", StatusConstant.NORMAL);

        return list(queryWrapper);
    }

    @Override
    public List<TaShopKeeper> getByPerson(String personId) {
        if (StringUtils.isEmpty(personId)) {
            return null;
        }

        QueryWrapper<TaShopKeeper> queryWrapper = new QueryWrapper<TaShopKeeper>()
                .eq("person_id", personId)
                .eq("status", StatusConstant.NORMAL);

        List<TaShopKeeper> list = list(queryWrapper);
        if (null != list && list.size() > 0) {
            for (TaShopKeeper keeper: list) {
                keeper.setTaShop(iTaShopService.getById(keeper.getShopId()));
            }
        }

        return list;
    }

    @Override
    public TaShopKeeper getByPhone(String phone, String shopId) {
        QueryWrapper<TaShopKeeper> queryWrapper = new QueryWrapper<TaShopKeeper>()
                .eq("shop_id", shopId)
                .eq("phone", phone)
                .gt("status", StatusConstant.DELETE)
                .last("limit 1");

        return getOne(queryWrapper);
    }
}
